@@ -123,8 +123,8 @@ function(
 	map = NULL,
     Pi = NULL,
     fold = NULL,
-    niter = 20000,
-    nburn = 12000,
+    niter = NULL,
+    nburn = NULL,
 	thin = 5,
     windsize = NULL,
 	windnum = NULL,
@@ -205,6 +205,12 @@ function(
 	}else{
 		windindx <- NULL
 	}
+	if(is.null(niter)){
+		niter <- ifelse(method == "BayesR", 50000, 20000)
+	}
+	if(is.null(nburn)){
+		nburn <- ifelse(method == "BayesR", 30000, 12000)
+	}
 	if(thin >= (niter - nburn))	stop("bad setting for collecting frequency 'thin'.")
 	if(printfreq <= 0)	verbose <- FALSE
 	if(is.null(Pi)){
